import * as request from "superagent";
import * as FantasyHockeyTypes from "./types";
/**
 * Gets a list of communication messages in the configured league/season
 * @param nhlSeason The year of the fantasy hockey season (i.e. `2020` for the 2019-2020 season)
 * @param fantasyLeagueId The ID of the ESPN fantasy hockey league
 * @param espnAuthCookie The value of the `espn_s2` cookie to be used for authentication
 * @param filter A filter to apply when pulling the list of messages
 */
export declare function getMessages(nhlSeason: number, fantasyLeagueId: string, espnAuthCookie: string, filter?: FantasyHockeyTypes.MessageFilter): Promise<FantasyHockeyTypes.MessageTopic[]>;
/**
 * Gets a list of active players in the configured season
 * @param nhlSeason The year of the fantasy hockey season (i.e. `2020` for the 2019-2020 season)
 * @param filter A filter to apply when pulling the list of players
 */
export declare function getPlayers(nhlSeason: number, filter: FantasyHockeyTypes.PlayerFilter): Promise<FantasyHockeyTypes.NhlPlayer[]>;
/**
 * Gets Info on the fantasy hockey league
 * @param nhlSeason The year of the fantasy hockey season (i.e. `2020` for the 2019-2020 season)
 * @param fantasyLeagueId The ID of the ESPN fantasy hockey league
 * @param espnAuthCookie The value of the `espn_s2` cookie to be used for authentication
 */
export declare function getLeagueData(nhlSeason: number, fantasyLeagueId: string, espnAuthCookie: string): Promise<FantasyHockeyTypes.FhLeagueData>;
/**
 * Gets info on the all NHL teams
 * @param nhlSeason The year of the fantasy hockey season (i.e. `2020` for the 2019-2020 season)
 * @param espnAuthCookie The value of the `espn_s2` cookie to be used for authentication
 */
export declare function getNhlTeamData(nhlSeason: number, espnAuthCookie: string): Promise<FantasyHockeyTypes.FantasyHockeyInfoResponse>;
/**
 * Makes an HTTP GET request
 * @param url The URL for the request
 * @param headers The headers to set for the request
 */
export declare function httpGetRequest(url: string, headers?: {
    [key: string]: string;
}): Promise<request.Response>;
/**
 * Makes an HTTP POST request
 * @param url The URL for the request
 * @param headers The headers to set for the request
 * @param data The request body to send
 */
export declare function httpPostRequest(url: string, headers?: {
    [key: string]: string;
}, data?: string | object): Promise<request.Response>;
//# sourceMappingURL=data-access-methods.d.ts.map