"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.waitUntilTableNotExists = exports.waitForTableNotExists = void 0;
const util_waiter_1 = require("@aws-sdk/util-waiter");
const DescribeTableCommand_1 = require("../commands/DescribeTableCommand");
const checkState = async (client, input) => {
    let reason;
    try {
        const result = await client.send(new DescribeTableCommand_1.DescribeTableCommand(input));
        reason = result;
    }
    catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "ResourceNotFoundException") {
            return { state: util_waiter_1.WaiterState.SUCCESS, reason };
        }
    }
    return { state: util_waiter_1.WaiterState.RETRY, reason };
};
const waitForTableNotExists = async (params, input) => {
    const serviceDefaults = { minDelay: 20, maxDelay: 120 };
    return (0, util_waiter_1.createWaiter)({ ...serviceDefaults, ...params }, input, checkState);
};
exports.waitForTableNotExists = waitForTableNotExists;
const waitUntilTableNotExists = async (params, input) => {
    const serviceDefaults = { minDelay: 20, maxDelay: 120 };
    const result = await (0, util_waiter_1.createWaiter)({ ...serviceDefaults, ...params }, input, checkState);
    return (0, util_waiter_1.checkExceptions)(result);
};
exports.waitUntilTableNotExists = waitUntilTableNotExists;
