import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DynamoDBClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DynamoDBClient";
import { ExecuteStatementInput, ExecuteStatementOutput } from "../models/models_0";
export interface ExecuteStatementCommandInput extends ExecuteStatementInput {
}
export interface ExecuteStatementCommandOutput extends ExecuteStatementOutput, __MetadataBearer {
}
/**
 * <p>This operation allows you to perform reads and singleton writes on data stored in
 *             DynamoDB, using PartiQL.</p>
 *         <p>For PartiQL reads (<code>SELECT</code> statement), if the total number of processed
 *             items exceeds the maximum dataset size limit of 1 MB, the read stops and results are
 *             returned to the user as a <code>LastEvaluatedKey</code> value to continue the read in a
 *             subsequent operation. If the filter criteria in <code>WHERE</code> clause does not match
 *             any data, the read will return an empty result set.</p>
 *         <p>A single <code>SELECT</code> statement response can return up to the maximum number of
 *             items (if using the Limit parameter) or a maximum of 1 MB of data (and then apply any
 *             filtering to the results using <code>WHERE</code> clause). If
 *                 <code>LastEvaluatedKey</code> is present in the response, you need to paginate the
 *             result set.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DynamoDBClient, ExecuteStatementCommand } from "@aws-sdk/client-dynamodb"; // ES Modules import
 * // const { DynamoDBClient, ExecuteStatementCommand } = require("@aws-sdk/client-dynamodb"); // CommonJS import
 * const client = new DynamoDBClient(config);
 * const command = new ExecuteStatementCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ExecuteStatementCommandInput} for command's `input` shape.
 * @see {@link ExecuteStatementCommandOutput} for command's `response` shape.
 * @see {@link DynamoDBClientResolvedConfig | config} for DynamoDBClient's `config` shape.
 *
 */
export declare class ExecuteStatementCommand extends $Command<ExecuteStatementCommandInput, ExecuteStatementCommandOutput, DynamoDBClientResolvedConfig> {
    readonly input: ExecuteStatementCommandInput;
    constructor(input: ExecuteStatementCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DynamoDBClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ExecuteStatementCommandInput, ExecuteStatementCommandOutput>;
    private serialize;
    private deserialize;
}
