import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { GetSMSAttributesInput, GetSMSAttributesResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, SNSClientResolvedConfig } from "../SNSClient";
export interface GetSMSAttributesCommandInput extends GetSMSAttributesInput {
}
export interface GetSMSAttributesCommandOutput extends GetSMSAttributesResponse, __MetadataBearer {
}
/**
 * <p>Returns the settings for sending SMS messages from your Amazon Web Services account.</p>
 *         <p>These settings are set with the <code>SetSMSAttributes</code> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SNSClient, GetSMSAttributesCommand } from "@aws-sdk/client-sns"; // ES Modules import
 * // const { SNSClient, GetSMSAttributesCommand } = require("@aws-sdk/client-sns"); // CommonJS import
 * const client = new SNSClient(config);
 * const command = new GetSMSAttributesCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link GetSMSAttributesCommandInput} for command's `input` shape.
 * @see {@link GetSMSAttributesCommandOutput} for command's `response` shape.
 * @see {@link SNSClientResolvedConfig | config} for SNSClient's `config` shape.
 *
 */
export declare class GetSMSAttributesCommand extends $Command<GetSMSAttributesCommandInput, GetSMSAttributesCommandOutput, SNSClientResolvedConfig> {
    readonly input: GetSMSAttributesCommandInput;
    constructor(input: GetSMSAttributesCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: SNSClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetSMSAttributesCommandInput, GetSMSAttributesCommandOutput>;
    private serialize;
    private deserialize;
}
